@@ -1,4 +1,4 @@
-from typing import Optional, List, Dict, Generator
+from typing import Optional, List, Dict, Generator, Tuple
 from dataclasses import dataclass
 import logging
 from kaizen.helpers import parser
@@ -160,7 +160,7 @@ class CodeReviewer:
 
         reviews.extend(self.check_sensitive_files(pull_request_files))
 
-        topics = self._merge_topics(reviews)
+        categories = self._merge_categories(reviews)
         prompt_cost, completion_cost = self.provider.get_usage_cost(
             total_usage=self.total_usage
         )
@@ -168,7 +168,7 @@ class CodeReviewer:
         return ReviewOutput(
             usage=self.total_usage,
             model_name=self.provider.model,
-            topics=topics,
+            topics=categories,
             issues=reviews,
             code_quality=code_quality,
             cost={"prompt_cost": prompt_cost, "completion_cost": completion_cost},
@@ -197,7 +197,7 @@ class CodeReviewer:
         pull_request_desc: str,
         user: Optional[str],
         reeval_response: bool,
-    ) -> List[Dict]:
+    ) -> Tuple[List[Dict], Optional[float]]:
         self.logger.debug("Processing based on files")
         reviews = []
         code_quality = None
@@ -208,13 +208,13 @@ class CodeReviewer:
             user,
             reeval_response,
         )
-        for file_review, quality in file_chunks_generator:
-            reviews.extend(file_review)
-            if quality:
-                if code_quality and code_quality > quality:
-                    code_quality = quality
-                else:
-                    code_quality = quality
+        for result in file_chunks_generator:
+            if result:  # Check if the result is not None
+                file_review, quality = result
+                reviews.extend(file_review)
+                if quality:
+                    if code_quality is None or quality < code_quality:
+                        code_quality = quality
         return reviews, code_quality
 
     def _process_files_generator(
@@ -224,7 +224,7 @@ class CodeReviewer:
         pull_request_desc: str,
         user: Optional[str],
         reeval_response: bool,
-    ) -> Generator[List[Dict], None, None]:
+    ) -> Generator[Optional[Tuple[List[Dict], Optional[float]]], None, None]:
         combined_diff_data = ""
         available_tokens = self.provider.available_tokens(FILE_CODE_REVIEW_PROMPT)
         for file in pull_request_files:
@@ -253,13 +253,16 @@ class CodeReviewer:
                 )
                 combined_diff_data = f"\n---->\nFile Name: {filename}\nPatch Details: {parser.patch_to_combined_chunks(patch_details,  self.ignore_deletions)}"
 
-        yield self._process_file_chunk(
-            combined_diff_data,
-            pull_request_title,
-            pull_request_desc,
-            user,
-            reeval_response,
-        )
+        if combined_diff_data:
+            yield self._process_file_chunk(
+                combined_diff_data,
+                pull_request_title,
+                pull_request_desc,
+                user,
+                reeval_response,
+            )
+        else:
+            yield None  # Yield None if there's no data to process
 
     def _process_file_chunk(
         self,
@@ -268,9 +271,9 @@ class CodeReviewer:
         pull_request_desc: str,
         user: Optional[str],
         reeval_response: bool,
-    ) -> List[Dict]:
+    ) -> Optional[Tuple[List[Dict], Optional[float]]]:
         if not diff_data:
-            return []
+            return None
         prompt = FILE_CODE_REVIEW_PROMPT.format(
             FILE_PATCH=diff_data,
         )
@@ -283,7 +286,7 @@ class CodeReviewer:
         if reeval_response:
             resp = self._reevaluate_response(prompt, resp, user)
 
-        return resp["review"], resp.get("code_quality_percentage", None)
+        return resp.get("review", []), resp.get("code_quality_percentage", None)
 
     def _reevaluate_response(self, prompt: str, resp: str, user: Optional[str]) -> str:
         new_prompt = PR_REVIEW_EVALUATION_PROMPT.format(
@@ -301,11 +304,11 @@ class CodeReviewer:
         return resp
 
     @staticmethod
-    def _merge_topics(reviews: List[Dict]) -> Dict[str, List[Dict]]:
-        topics = {}
+    def _merge_categories(reviews: List[Dict]) -> Dict[str, List[Dict]]:
+        categories = {}
         for review in reviews:
-            topics.setdefault(review["topic"], []).append(review)
-        return topics
+            categories.setdefault(review["category"], []).append(review)
+        return categories
 
     def check_sensitive_files(self, pull_request_files: list):
         reviews = []
@@ -321,18 +324,18 @@ class CodeReviewer:
                             line = patch.split(" ")[2].split(",")[0][1:]
                         reviews.append(
                             {
-                                "topic": category,
-                                "comment": "Changes made to sensitive file",
-                                "confidence": "critical",
-                                "reason": f"Changes were made to {file_name}, which needs review",
-                                "solution": "NA",
+                                "category": category,
+                                "description": "Changes made to sensitive file",
+                                "impact": "critical",
+                                "recommendation": f"Changes were made to {file_name}, which needs review",
+                                "current_code": "NA",
                                 "fixed_code": "",
                                 "start_line": line,
                                 "end_line": line,
                                 "side": "RIGHT",
-                                "file_name": file_name,
+                                "file_path": file_name,
                                 "sentiment": "negative",
-                                "severity_level": 10,
+                                "severity": 10,
                             }
                         )
         return reviews
